@@ -10,7 +10,6 @@
 #   exportMethods(fun)
 setGeneric(name = "predict")
 
-
 # Controlflows -------------------------------------------------------------------------------------------------
 # Steps performed by all models but different between base (no cov) and covariate models
 
@@ -18,7 +17,7 @@ setGeneric(name = "predict")
 setGeneric("clv.controlflow.estimate.check.inputs", def=function(clv.fitted,  start.params.model, optimx.args, verbose,...)
   standardGeneric("clv.controlflow.estimate.check.inputs"))
 
-setGeneric("clv.controlflow.estimate.put.inputs", def=function(clv.fitted, verbose, ...)
+setGeneric("clv.controlflow.estimate.put.inputs", def=function(clv.fitted, start.params.model, optimx.args, verbose, ...)
   standardGeneric("clv.controlflow.estimate.put.inputs"))
 
 setGeneric("clv.controlflow.estimate.generate.start.params", def=function(clv.fitted, start.params.model, verbose,...)
@@ -32,7 +31,7 @@ setGeneric("clv.controlflow.estimate.process.post.estimation", def=function(clv.
 
 
 # . Predict -----------------------------------------------------------------------------------------------
-setGeneric("clv.controlflow.predict.check.inputs", def = function(clv.fitted, verbose, ...)
+setGeneric("clv.controlflow.predict.check.inputs", def = function(clv.fitted, verbose, uncertainty, num.boots, level, ...)
   standardGeneric("clv.controlflow.predict.check.inputs"))
 
 setGeneric("clv.controlflow.predict.set.prediction.params", def = function(clv.fitted)
@@ -51,7 +50,6 @@ setGeneric(name = "clv.controlflow.predict.post.process.prediction.table", def =
   standardGeneric("clv.controlflow.predict.post.process.prediction.table"))
 
 
-
 # .. Newdata: replace data in existing model -----------------------------------------------------------------
 # For plot and predict
 setGeneric("clv.controlflow.check.newdata", def = function(clv.fitted, user.newdata, ...)
@@ -68,7 +66,24 @@ setGeneric("clv.controlflow.check.prediction.params", def = function(clv.fitted)
 setGeneric("clv.controlflow.plot.check.inputs", def = function(obj, prediction.end, cumulative, plot, label.line, verbose)
   standardGeneric("clv.controlflow.plot.check.inputs"))
 
+# . Predict new customer -----------------------------------------------------------------------------------------
+setGeneric("clv.controlflow.predict.new.customer", def = function(clv.fitted, clv.newcustomer){
+  standardGeneric("clv.controlflow.predict.new.customer")
+})
 
+# . Bootstrapping ------------------------------------------------------------------------------------------
+
+# Estimate the model again on new data with its original specification
+# pass arguments incl optimx.args and overwrite any existing settings in ...
+setGeneric("clv.fitted.estimate.same.specification.on.new.data", function(clv.fitted, newdata, ...){
+  standardGeneric("clv.fitted.estimate.same.specification.on.new.data")
+})
+
+# Generate many predictions by re-fitting the given model on bootstrapped
+# transaction data and predicting on it
+setGeneric("clv.fitted.bootstrap.predictions", function(clv.fitted, num.boots, verbose, ...){
+  standardGeneric("clv.fitted.bootstrap.predictions")
+})
 
 
 
@@ -146,9 +161,16 @@ setGeneric(name="clv.model.vcov.jacobi.diag", def=function(clv.model, clv.fitted
 setGeneric(name="clv.model.process.newdata", def=function(clv.model, clv.fitted, user.newdata, verbose)
   standardGeneric("clv.model.process.newdata"))
 
+# .. PMF --------------------------------------------------------------------------------------------------------------------
 setGeneric(name="clv.model.pmf", def=function(clv.model, clv.fitted, x)
   standardGeneric("clv.model.pmf"))
 
+# .. New customer expectation -----------------------------------------------------------------------------------------------
+# predict unconditional expectation until individual t_i for all customers in clv.fitted@clv.data
+setGeneric("clv.model.predict.new.customer.unconditional.expectation", function(clv.model, clv.fitted, clv.newcustomer, t)
+  standardGeneric("clv.model.predict.new.customer.unconditional.expectation"))
+
+
 
 # . For covariate models -----------------------------------------------------------------------------------------------------------
 
@@ -191,6 +213,13 @@ setGeneric("clv.time.format.timepoint", function(clv.time, timepoint)
   standardGeneric("clv.time.format.timepoint"))
 
 
+# clv.data ----------------------------------------------------------------------------------------------------
+# Create clv.data object with same config asbut only transactions and covariates of given ids
+setGeneric("clv.data.create.bootstrapping.data", def = function(clv.data, ids){
+  standardGeneric("clv.data.create.bootstrapping.data")
+})
+
+
 
 # S3 Generics ---------------------------------------------------------------
 #' Coerce to clv.data object
