@@ -4,7 +4,6 @@ data("apparelTrans")
 data("cdnow")
 
 # Parameter data.transactions ------------------------------------------------------------------------------------
-context("Inputchecks - clvdata - Parameter data.transactions")
 
 test_that("Fails if missing / NA / NULL", {
   expect_error(clvdata(data.transactions = , time.unit = "w",date.format = "ymd"))
@@ -74,7 +73,6 @@ test_that("Has no default argument", {
 
 
 # Parameter date.format ------------------------------------------------------------------------------------
-context("Inputchecks - clvdata - Parameter date.format")
 
 test_that("Fails if missing/NULL/NA", {
   expect_error(clvdata(data.transactions = cdnow, time.unit = "w"),
@@ -90,7 +88,7 @@ test_that("Fails if not character", {
   expect_error(clvdata(date.format = lubridate::ymd, data.transactions = cdnow, time.unit = "w"), regexp = "character")
   expect_error(clvdata(date.format = Sys.Date(), data.transactions = cdnow, time.unit = "w"), regexp = "character")
 
-  expect_error(clvdata(date.format = character(0), data.transactions = cdnow, time.unit = "w"), regexp = "single")
+  expect_error(clvdata(date.format = character(0), data.transactions = cdnow, time.unit = "w"), regexp = "exactly 1 element")
   expect_error(clvdata(date.format = list("ymd"), data.transactions = cdnow, time.unit = "w"), regexp = "character")
   expect_error(clvdata(date.format = data.frame("ymd"), data.transactions = cdnow, time.unit = "w"), regexp = "character")
 })
@@ -105,8 +103,8 @@ test_that("Fails if date.format wrong format", {
 })
 
 test_that("Fails if has multiple", {
-  expect_error(clvdata(date.format = c("ymd", "ymd"), data.transactions = cdnow, time.unit = "w"), regexp = "single")
-  expect_error(clvdata(date.format = c("ymd", "dmy"), data.transactions = cdnow, time.unit = "w"), regexp = "single")
+  expect_error(clvdata(date.format = c("ymd", "ymd"), data.transactions = cdnow, time.unit = "w"), regexp = "exactly 1 element")
+  expect_error(clvdata(date.format = c("ymd", "dmy"), data.transactions = cdnow, time.unit = "w"), regexp = "exactly 1 element")
 })
 
 
@@ -117,8 +115,6 @@ test_that("Has no default argument", {
 
 # Parameter time.unit --------------------------------------------------------------------------------
 
-context("Inputchecks - clvdata - Parameter time.unit")
-
 test_that("Fails if missing/NULL/NA", {
   expect_error(clvdata(data.transactions = cdnow, date.format="ymd"),
                regexp = "missing")
@@ -141,7 +137,7 @@ test_that("Fails if not character", {
 
 test_that("Fails if wrong time.unit format", {
   expect_error(clvdata(time.unit = character(0), data.transactions = cdnow, date.format="ymd"),
-               regexp = "one single element")
+               regexp = "exactly 1 element")
   expect_error(clvdata(time.unit = "beeks", data.transactions = cdnow, date.format="ymd"),
                regexp = "one of the following")
   expect_error(clvdata(time.unit = "decade", data.transactions = cdnow, date.format="ymd"),
@@ -154,9 +150,9 @@ test_that("Fails if wrong time.unit format", {
 
 test_that("Fails if has multiple", {
   expect_error(clvdata(time.unit = c("weeks", "years"), data.transactions = cdnow, date.format="ymd"),
-               regexp = "one single element")
+               regexp = "exactly 1 element")
   expect_error(clvdata(time.unit = c("weeks", "weeks"), data.transactions = cdnow, date.format="ymd"),
-               regexp = "single element")
+               regexp = "exactly 1 element")
 })
 
 test_that("Has no default argument", {
@@ -166,7 +162,6 @@ test_that("Has no default argument", {
 
 
 # Parameter estimation.split ---------------------------------------------------------------------------
-context("Inputchecks - clvdata - Parameter estimation.split")
 
 test_that("Fails if NA",{
   expect_error(clvdata(estimation.split = NA_real_,time.unit = "w", data.transactions = cdnow, date.format="ymd"),
@@ -182,11 +177,11 @@ test_that("Fails if not numeric, character, or date",{
                regexp = "can be converted")
 
   expect_error(clvdata(estimation.split = character(0),time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "one single element")
+               regexp = "exactly one single element")
   expect_error(clvdata(estimation.split = numeric(),time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "one single element")
+               regexp = "exactly one single element")
   expect_error(clvdata(estimation.split = as.Date(character(0)),time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "one single element")
+               regexp = "exactly one single element")
   expect_error(clvdata(estimation.split = as.Date(NA_character_),time.unit = "w", data.transactions = cdnow, date.format="ymd"),
                regexp = "any NA")
 })
@@ -233,7 +228,6 @@ test_that("Has default argument NULL",{
 
 
 # Parameter name.id ------------------------------------------------------------------------------------
-context("Inputchecks - clvdata - Parameter name.id")
 
 test_that("Fails if NA/NULL", {
   expect_error(clvdata(name.id = NULL, time.unit = "w", data.transactions = cdnow, date.format="ymd"),
@@ -241,7 +235,7 @@ test_that("Fails if NA/NULL", {
   expect_error(clvdata(name.id = NA_character_, time.unit = "w", data.transactions = cdnow, date.format="ymd"),
                regexp = "any NA")
   expect_error(clvdata(name.id = character(0), time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "single element")
+               regexp = "exactly 1 element")
 })
 
 test_that("Fails if not character", {
@@ -255,9 +249,9 @@ test_that("Fails if not character", {
 
 test_that("Fails if multiple", {
   expect_error(clvdata(name.id = c("Id", "Id"), time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "single element")
+               regexp = "exactly 1 element")
   expect_error(clvdata(name.id = c("Id", "Date"), time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "single element")
+               regexp = "exactly 1 element")
 })
 
 test_that("Fails if not in transaction data", {
@@ -280,7 +274,6 @@ test_that("Has default argument Id",{
 
 
 # Parameter name.date ------------------------------------------------------------------------------------
-context("Inputchecks - clvdata - Parameter name.date")
 
 test_that("Fails if NA/NULL", {
   expect_error(clvdata(name.date = NULL, time.unit = "w", data.transactions = cdnow, date.format="ymd"),
@@ -288,7 +281,7 @@ test_that("Fails if NA/NULL", {
   expect_error(clvdata(name.date = NA_character_, time.unit = "w", data.transactions = cdnow, date.format="ymd"),
                regexp = "any NA")
   expect_error(clvdata(name.date = character(0), time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "single element")
+               regexp = "exactly 1 element")
 })
 
 test_that("Fails if not character", {
@@ -302,9 +295,9 @@ test_that("Fails if not character", {
 
 test_that("Fails if multiple", {
   expect_error(clvdata(name.date = c("Id", "Id"), time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "single element")
+               regexp = "exactly 1 element")
   expect_error(clvdata(name.date = c("Id", "Date"), time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "single element")
+               regexp = "exactly 1 element")
 })
 
 test_that("Fails if not in transaction data", {
@@ -331,14 +324,12 @@ test_that("Has default argument Date",{
 
 
 # Parameter name.price ------------------------------------------------------------------------------------
-context("Inputchecks - clvdata - Parameter name.price")
-
 test_that("Fails if NA/empty", {
   # Null is allowed to express no spending data
   expect_error(clvdata(name.price = NA_character_, time.unit = "w", data.transactions = cdnow, date.format="ymd"),
                regexp = "any NA")
   expect_error(clvdata(name.price = character(0), time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "single element")
+               regexp = "exactly 1 element")
 })
 
 test_that("Fails if not character", {
@@ -352,9 +343,9 @@ test_that("Fails if not character", {
 
 test_that("Fails if multiple", {
   expect_error(clvdata(name.price = c("Id", "Id"), time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "single element")
+               regexp = "exactly 1 element")
   expect_error(clvdata(name.price = c("Id", "Date"), time.unit = "w", data.transactions = cdnow, date.format="ymd"),
-               regexp = "single element")
+               regexp = "exactly 1 element")
 })
 
 test_that("Fails if not in transaction data", {
